pub struct MainArgs {
pub debug_count: u8,
pub ssh_logging: bool,
pub test_mode: bool,
pub profile: Option<String>,
pub interactive: bool,
pub pass_entry: Option<String>,
pub command: Option<MainCommand>,
}Expand description
Parsed top-level command-line arguments.
Fields
debug_count: u8Debug verbosity requested on the CLI (-d safe, -dd raw).
ssh_logging: boolEnable SSH session logging to file
test_mode: boolIn test mode, ignore config logging settings and only honor CLI logging flags
profile: Option<String>Argument to pass for configuration profiles
interactive: boolLaunch interactive session manager TUI
pass_entry: Option<String>Override the password entry to use for a direct protocol launch.
command: Option<MainCommand>Selected command, if any.