pub struct AgentClient { /* private fields */ }Expand description
Client for querying and controlling the local unlock agent. Client used by runtime command paths to communicate with the unlock agent.
Implementations
Sourceimpl AgentClient
impl AgentClient
Sourcepub fn new() -> Result<Self, AgentError>
pub fn new() -> Result<Self, AgentError>
Create a client bound to the default ~/.color-ssh runtime paths.
Sourcepub fn status(&self) -> Result<VaultStatus, AgentError>
pub fn status(&self) -> Result<VaultStatus, AgentError>
Query current vault status.
Sourcepub fn unlock(
&self,
master_password: &str,
policy: UnlockPolicy,
) -> Result<VaultStatus, AgentError>
pub fn unlock( &self, master_password: &str, policy: UnlockPolicy, ) -> Result<VaultStatus, AgentError>
Unlock the vault using a master password and timeout policy.
Sourcepub fn entry_status(&self, name: &str) -> Result<AgentEntryStatus, AgentError>
pub fn entry_status(&self, name: &str) -> Result<AgentEntryStatus, AgentError>
Query whether a vault entry exists and whether the vault is unlocked.
Authorize one short-lived askpass token for the named vault entry.
Sourcepub fn get_secret(&self, token: &str) -> Result<SensitiveString, AgentError>
pub fn get_secret(&self, token: &str) -> Result<SensitiveString, AgentError>
Resolve a secret by askpass token.
Sourcepub fn lock(&self) -> Result<VaultStatus, AgentError>
pub fn lock(&self) -> Result<VaultStatus, AgentError>
Request an explicit vault lock and agent shutdown.