pub struct AgentEntryStatus {
pub status: VaultStatus,
pub exists: bool,
}Expand description
Client for querying and controlling the local unlock agent. Result of checking whether a vault entry is available for use.
Fields
status: VaultStatusCurrent vault lock/unlock status.
exists: boolWhether the queried entry name exists in the vault.