Module ipc

Module ipc 

Local IPC protocol used by the password-vault unlock agent.

Structs

AgentRequest
Top-level client request wrapper.
UnlockPolicy
Unlock timeout policy sent to the agent.
VaultStatus
Current vault state reported by the agent.
VaultStatusEvent
Broadcast event stored in the status event file.

Enums

AgentRequestPayload
Request payload sent from clients to the unlock agent.
AgentResponse
Response envelope returned by the unlock agent.
ListenerBindResult
Result of trying to bind the agent socket listener.
VaultStatusEventKind
Emitted vault status transition kind.

Functions

bind_listener
Bind the unlock-agent local socket listener.
broadcast_vault_status_event
Persist a vault status event for local consumers.
cleanup_endpoint
Remove endpoint resources used by the unlock agent.
connect
Connect directly to the current agent endpoint.
read_request
Read one IPC request from a connected stream.
read_vault_status_event
Read the latest persisted vault status event.
send_request
Send one request and wait for one response.
write_response
Write one IPC response to a connected stream.