pub struct AuthSettings {
pub idle_timeout_seconds: u64,
pub session_timeout_seconds: u64,
pub direct_password_autologin: bool,
pub tui_password_autologin: bool,
}Expand description
Authentication settings for the shared password vault.
Fields
idle_timeout_seconds: u64Idle timeout in seconds before the unlock agent relocks the vault.
session_timeout_seconds: u64Maximum unlock lifetime in seconds before the agent relocks regardless of activity.
direct_password_autologin: boolWhether direct cossh ssh host launches should attempt password auto-login.
tui_password_autologin: boolWhether TUI launches should attempt password auto-login.