pub struct SshHostTreeModel {
pub root: TreeFolder,
pub hosts: Vec<SshHost>,
}Expand description
Parsed host record and tree model types from SSH config. Parsed SSH host data and include graph as a folder tree.
Fields
root: TreeFolderRoot folder (~/.ssh/config).
hosts: Vec<SshHost>Flattened host list in discovery order.