Local IPC protocol used by the password-vault unlock agent.
Structs
- Agent
Request - Top-level client request wrapper.
- Unlock
Policy - Unlock timeout policy sent to the agent.
- Vault
Status - Current vault state reported by the agent.
- Vault
Status Event - Broadcast event stored in the status event file.
Enums
- Agent
Request Payload - Request payload sent from clients to the unlock agent.
- Agent
Response - Response envelope returned by the unlock agent.
- Listener
Bind Result - Result of trying to bind the agent socket listener.
- Vault
Status Event Kind - Emitted vault status transition kind.
Functions
- bind_
listener - Bind the unlock-agent local socket listener.
- broadcast_
vault_ status_ event - Persist a vault status event for local consumers.
- cleanup_
endpoint - Remove endpoint resources used by the unlock agent.
- connect
- Connect directly to the current agent endpoint.
- read_
request - Read one IPC request from a connected stream.
- read_
vault_ status_ event - Read the latest persisted vault status event.
- send_
request - Send one request and wait for one response.
- write_
response - Write one IPC response to a connected stream.