pub struct Logger { /* private fields */ }Expand description
Runtime logger for debug and SSH session output.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn enable_debug(&self)
pub fn enable_debug(&self)
Enable safe debug logging.
Sourcepub fn enable_debug_with_verbosity(&self, verbosity: DebugVerbosity)
pub fn enable_debug_with_verbosity(&self, verbosity: DebugVerbosity)
Enable debug logging with explicit verbosity.
Sourcepub fn disable_debug(&self)
pub fn disable_debug(&self)
Disable debug logging and flush pending messages.
Sourcepub fn enable_ssh_logging(&self)
pub fn enable_ssh_logging(&self)
Enable SSH session logging.
Sourcepub fn disable_ssh_logging(&self)
pub fn disable_ssh_logging(&self)
Disable SSH session logging.
Sourcepub fn debug_verbosity(&self) -> DebugVerbosity
pub fn debug_verbosity(&self) -> DebugVerbosity
Return currently configured debug verbosity.
Sourcepub fn is_debug_enabled(&self) -> bool
pub fn is_debug_enabled(&self) -> bool
Returns true when safe or raw debug is enabled.
Sourcepub fn is_raw_debug_enabled(&self) -> bool
pub fn is_raw_debug_enabled(&self) -> bool
Returns true only when raw debug logging is enabled.
Sourcepub fn is_ssh_logging_enabled(&self) -> bool
pub fn is_ssh_logging_enabled(&self) -> bool
Returns true when SSH session logging is enabled.
Sourcepub fn log_debug(&self, message: &str) -> Result<(), LogError>
pub fn log_debug(&self, message: &str) -> Result<(), LogError>
Write a debug-level message if debug logging is enabled.
Sourcepub fn log_info(&self, message: &str) -> Result<(), LogError>
pub fn log_info(&self, message: &str) -> Result<(), LogError>
Write an info-level message if debug logging is enabled.
Sourcepub fn log_warn(&self, message: &str) -> Result<(), LogError>
pub fn log_warn(&self, message: &str) -> Result<(), LogError>
Write a warning-level message if debug logging is enabled.
Sourcepub fn log_error(&self, message: &str) -> Result<(), LogError>
pub fn log_error(&self, message: &str) -> Result<(), LogError>
Write an error-level message if debug logging is enabled.
Sourcepub fn flush_debug(&self) -> Result<(), LogError>
pub fn flush_debug(&self) -> Result<(), LogError>
Flush debug logger output.
Sourcepub fn log_ssh(&self, message: &str) -> Result<(), LogError>
pub fn log_ssh(&self, message: &str) -> Result<(), LogError>
Write one sanitized SSH session log line when enabled.
Sourcepub fn log_ssh_raw(&self, message: &str) -> Result<(), LogError>
pub fn log_ssh_raw(&self, message: &str) -> Result<(), LogError>
Write one raw SSH chunk when enabled.
Write one shared raw SSH chunk without cloning the string.